@@ -95,32 +95,30 @@ impl<T: ObjectType> ContainerType for QueryRoot<T> {
         if !ctx.schema_env.registry.disable_introspection && !ctx.query_env.disable_introspection {
             if ctx.item.node.name.node == "__schema" {
                 let ctx_obj = ctx.with_selection_set(&ctx.item.node.selection_set);
-                return Ok(Some(
-                    OutputType::resolve(
-                        &__Schema {
-                            registry: &ctx.schema_env.registry,
-                        },
-                        &ctx_obj,
-                        ctx.item,
-                    )
-                    .await,
-                ));
+                return OutputType::resolve(
+                    &__Schema {
+                        registry: &ctx.schema_env.registry,
+                    },
+                    &ctx_obj,
+                    ctx.item,
+                )
+                .await
+                .map(Some);
             } else if ctx.item.node.name.node == "__type" {
                 let type_name: String = ctx.param_value("name", None)?;
                 let ctx_obj = ctx.with_selection_set(&ctx.item.node.selection_set);
-                return Ok(Some(
-                    OutputType::resolve(
-                        &ctx.schema_env
-                            .registry
-                            .types
-                            .get(&type_name)
-                            .filter(|ty| ty.is_visible(ctx))
-                            .map(|ty| __Type::new_simple(&ctx.schema_env.registry, ty)),
-                        &ctx_obj,
-                        ctx.item,
-                    )
-                    .await,
-                ));
+                return OutputType::resolve(
+                    &ctx.schema_env
+                        .registry
+                        .types
+                        .get(&type_name)
+                        .filter(|ty| ty.is_visible(ctx))
+                        .map(|ty| __Type::new_simple(&ctx.schema_env.registry, ty)),
+                    &ctx_obj,
+                    ctx.item,
+                )
+                .await
+                .map(Some);
             }
         }
 
@@ -138,16 +136,15 @@ impl<T: ObjectType> ContainerType for QueryRoot<T> {
                 return Ok(Some(Value::List(res)));
             } else if ctx.item.node.name.node == "_service" {
                 let ctx_obj = ctx.with_selection_set(&ctx.item.node.selection_set);
-                return Ok(Some(
-                    OutputType::resolve(
-                        &Service {
-                            sdl: Some(ctx.schema_env.registry.export_sdl(true)),
-                        },
-                        &ctx_obj,
-                        ctx.item,
-                    )
-                    .await,
-                ));
+                return OutputType::resolve(
+                    &Service {
+                        sdl: Some(ctx.schema_env.registry.export_sdl(true)),
+                    },
+                    &ctx_obj,
+                    ctx.item,
+                )
+                .await
+                .map(Some);
             }
         }
 
@@ -157,7 +154,11 @@ impl<T: ObjectType> ContainerType for QueryRoot<T> {
 
 #[async_trait::async_trait]
 impl<T: ObjectType> OutputType for QueryRoot<T> {
-    async fn resolve(&self, ctx: &ContextSelectionSet<'_>, _field: &Positioned<Field>) -> Value {
+    async fn resolve(
+        &self,
+        ctx: &ContextSelectionSet<'_>,
+        _field: &Positioned<Field>,
+    ) -> ServerResult<Value> {
         resolve_container(ctx, self).await
     }
 }
